import java.io.*;
import java.util.*;
import java.net.*;

public class Unicode2Tex {

    private static HashMap<Integer,String> table = new HashMap<Integer,String>();
    private static HashSet<Integer> warned       = new HashSet<Integer>();

    public static void main(String[] args) throws Exception {

        BufferedReader tabletxt =
            new BufferedReader(new InputStreamReader(Unicode2Tex.class
                                                     .getClassLoader().getResource("table.utf8.txt").openStream(),
                                                     "UTF-8"));
        String s = null;
        while ( (s = tabletxt.readLine()) != null ) {
            if (s.length() < 2) continue;
            s = s.substring(2);
            int code = Integer.parseInt(s.substring(0, s.indexOf(' ')) ,16);
            String tex = s.substring(s.indexOf(' ')+1).trim();
            table.put(code, tex);
        }
        tabletxt.close();

        BufferedReader in  = new BufferedReader(new InputStreamReader(System.in, "UTF-8"));
        PrintWriter    out = new PrintWriter(new OutputStreamWriter(System.out, "ASCII"));
        PrintWriter    err = new PrintWriter(new OutputStreamWriter(System.err, "UTF-8"));

        int c;
        while ( (c = in.read()) != -1 ) {
            int i = (c & 0xffff);
            s = table.get(c);

            switch ((char)i) {
                case '\n': out.println("\\\\"); break;
                case '\r': break;
                case ' ' : out.print("{\\phantom{X}}"); break;
                case '\\': out.print("{\\char`\\\\}"); break;
                case '~' : out.print("{\\rlap{\\lower.85ex\\hbox{\\large\\char126}}\\ }"); break;
                case '{' : out.print("{\\char123}"); break;
                case '}' : out.print("{\\char125}"); break;
                case '_' : out.print("{\\char95}"); break;
                case '$' : out.print("{\\$}"); break;
                case '%' : out.print("{\\%}"); break;
                case '&' : out.print("{\\&}"); break;
                case '^' : out.print("{\\text{\\textasciicircum}}"); break;
                case '`' : out.print("{`}"); break;
                default:
                    if (i >= 0x30 && i <= 0x7a) out.print((char)c);
                    else if (s != null) {
                        if (s.startsWith("$")) {
                            out.print("{\\rlap{"+s+"}\\ }");
                        } else {
                            out.print('{'+s+'}');
                        }
                    } else if (i < 127) {
                        out.print((char)c);
                    } else {
                        if (!warned.contains(i)) {
                            err.println("warning: character '"+c+"' (0x"+(Integer.toString(i, 16))+") not found in stix table");
                            err.flush();
                            warned.add(i);
                        }
                        out.print(c);
                    }
            }
        }
        out.flush();
        out.close();
    }

}